% script for testing one sided transforms

clear all, close all

diary off
dfile='figsec7.txt'
delete(dfile)
diary(dfile)

disp(' '), disp('figJ')
pappos=[2 2 6 6]
figure(1), clf, set(gcf,'paperposition',pappos,'position',(pappos-[1 1 0 0])*100), drawnow, pause(2)
fsze=24;

disp(' '), disp('basis functions')

T=100
N=50, P=0, 
nf=N+P, 
f=([1 nf]-(P+1)/2)/2/N, 
%f=([2 nf-1]-(P+1)/2)/2/N, 
%df=ones(1,nf); df([1 end])=df([1 end])-P/2; df=df/2/N

% Fourier basis
tax=-T/2:T/2;
theta=exp(i*2*pi*tax'*f);
subplot(4,2,1), pl=plot(tax,real(theta(:,1)),'bx-',tax,imag(theta(:,1)),'r+-'); axis([-T/2 T/2 -1 1])
set(pl,'markersize',4,'linewidth',5), set(gca,'XTick',-T/2:T/4:T/2)
subplot(4,2,2), pl=plot(tax,real(theta(:,2)),'bx-',tax,imag(theta(:,2)),'r+-'); axis([-T/2 T/2 -1 1])
set(pl,'markersize',4,'linewidth',5), set(gca,'XTick',-T/2:T/4:T/2)

% Gabor basis
sigma = sqrt(pi)*2, tau = 6*2
tw = -tau:tau;                  % window time axis
phi = exp(-pi*tw.^2/sigma^2/2); % window amplitude
phi = phi/sqrt(phi*phi');     % normalized to unit energy
sumphi2=sum(phi.^2), phimid=phi(tau+1)
phimat=diag(phi); psimat=phimat*exp(i*2*pi*tw'*f);
subplot(4,2,3), pl=plot(tw,real(psimat(:,1)),'bx-',tw,imag(psimat(:,1)),'r+-'); axis([-12 12 -.6 .6])
set(pl,'markersize',4,'linewidth',5), set(gca,'XTick',-12:6:12)
subplot(4,2,4), pl=plot(tw,real(psimat(:,2)),'bx-',tw,imag(psimat(:,2)),'r+-'); axis([-12 12 -.6 .6])
set(pl,'markersize',4,'linewidth',5), set(gca,'XTick',-12:6:12)

% Morlet basis
sigma = sqrt(pi)/f(1), tau = ceil(6/f(1))
tw = -tau:tau;                  % window time axis
phi = exp(-pi*tw.^2/sigma^2/2); % window amplitude
phi = phi/sqrt(phi*phi');     % normalized to unit energy
sumphi2=sum(phi.^2), phimid=phi(tau+1)
phimat=diag(phi); psimat=phimat*exp(i*2*pi*tw'*f(1));
subplot(4,2,5), pl=plot(tw,real(psimat(:,1)),'bx-',tw,imag(psimat(:,1)),'r+-'); axis([-1200 1200 -.06 .06])
set(pl,'markersize',4,'linewidth',5), set(gca,'XTick',[-12:6:12]*100)
sigma = sqrt(pi)/f(2), tau = ceil(6/f(2))
tw = -tau:tau;                  % window time axis
phi = exp(-pi*tw.^2/sigma^2/2); % window amplitude
phi = phi/sqrt(phi*phi');     % normalized to unit energy
sumphi2=sum(phi.^2), phimid=phi(tau+1)
phimat=diag(phi); psimat=phimat*exp(i*2*pi*tw'*f(2));
subplot(4,2,6), pl=plot(tw,real(psimat(:,1)),'bx-',tw,imag(psimat(:,1)),'r+-'); axis([-14 14 -.6 .6])
set(pl,'markersize',4,'linewidth',5), set(gca,'XTick',-14:7:14,'XLim',[-14 14])

% layered window
sigma = sqrt(pi)/6, tau = [12:48*2], maxtau=max(tau)
tw = -maxtau:maxtau;                  % window time axis
[yl,fax,dfax,phi]=osdlayer(1,tax,tax,N,sigma,tau,P);
phi=phi/sqrt(2);    % normalized to unit energy
sumphi2=sum(phi.^2), phimid=phi(maxtau+1)
phimat=diag(phi); psimat=phimat*exp(i*2*pi*tw'*f);
subplot(4,2,7), pl=plot(tw,real(psimat(:,1)),'bx-',tw,imag(psimat(:,1)),'r+-'); axis([-96 96 -.3 .3])
set(pl,'markersize',4,'linewidth',5), set(gca,'XTick',[-12:6:12]*8)
subplot(4,2,8), pl=plot(tw,real(psimat(:,2)),'bx-',tw,imag(psimat(:,2)),'r+-'); axis([-96 96 -.3 .3])
set(pl,'markersize',4,'linewidth',5), set(gca,'XTick',[-12:6:12]*8)

for ks=1:8, subplot(4,2,ks)
    set(gca,'linewidth',2,'fontsize',fsze)
    xlabel('t\prime','fontsize',fsze)
    if mod(ks,2), ylabel('\Psi (t\prime, 1)','fontsize',fsze), else  ylabel('\Psi (t\prime, N)','fontsize',fsze), end
    text(1.02,0.95,['(' char(96+ks) ')'],'units','normalized','verticalalignment','top','fontsize',fsze)
    apos=get(gca,'position'); apos=apos+.04*[1.25-2*mod(ks,2) (2.5-ceil(ks/2))/2 0 0]; set(gca,'position',apos)
end
print('temp.eps','-depsc2',['-F:' num2str(fsze-4)])
system('eps2eps temp.eps figJ.eps')
system('epstopdf figJ.eps');
delete temp.eps

%disp(' '), disp('random window transform')

%load savesig.mat    % load previous signal

%format long
%[yf2,fax2,dfax2]=tsdfourier(1,yt,tax,nf,pf);
%pwryf2=abs(yf2).^2; phsyf2=angle(yf2);
%iyf2=real(tsdfourier(-1,yf2,tax,nf,pf));
%resyf2=(iyf2.'-yt); rmsresyf2=sqrt(mean(resyf2.^2))
%[sum(iyf2.^2) dfax2*pwryf2 sumyt2], ans(2:3)./ans(1:2), 1./ans
%format short

%gam2=15, 
%taumax = 48 %max(tau(:));
%tw=-taumax:taumax;
%%phi2=1./(1+(tw-15).^2/gam2); 
%phi2=rand(1,2*taumax+1);
%phi2=phi2/sum(phi2)*2; 
%phi=sqrt(phi2);

%format long
%[yp,fax,dfax,phi]=osdgiven(1,yt,tax,nf,phi,pf);
%pwryp=abs(yp).^2; phsyp=angle(yp);
%iyp=osdgiven(-1,yp,tax,nf,phi,pf);
%resyp=(iyp-yt); rmsresyp=sqrt(mean(resyp.^2))
%[sum(iyp.^2) dfax*sum(pwryp,2) sumyt2], ans(2:3)./ans(1:2), 1./ans
%format short
%[phif2,faxphi,dfaxphi]=tsdfourier(1,phi/sqrt(2),1:length(phi),nf,1); 
%pwrphif2=abs(phif2).^2; 
%cvp=conv(dfaxphi'.*pwrphif2,[pwryf2(nf+[1:nf]); pwryf2; pwryf2(1:nf)]); 
%convpwrf=cvp(nf*3+[1:nf+mod(pf,2)])*2;
%convpwrt=conv(phi.^2/2,yt.^2);

%taxtau=1-taumax:nt+taumax;
%subplot(2,2,1), contour(taxtau,fax,pwryp), axis([1-12 nt+12 0 1/2])
%hold on, plot(tax,fq,'k-'), hold off
%subplot(2,2,2), plot(sum(pwryp,2),fax,'s-',convpwrf,fax,'d-'), ylim([0 1/2])
%subplot(2,2,3), plot(taxtau,dfax*pwryp,'s-',taxtau,convpwrt,'d-'), xlim([1-12 nt+12])
%subplot(2,2,4), semilogy(tax,abs(resyp),'s-')


diary off
