function [y,fax,dfax]=osdfourier(xtype,x,tax,nf,faxtype)
%   [y,fax,dfax]=osdfourier(xtype,x,tax,nf,faxtype) returns the forward or
%   inverse one-sided discrete Fourier transform of order nf for tax
%   with regular sampling (integer values) not necessarily uniform

if (nargin < 4) || (nargin > 5)
    help osdfourier, return
end
if  (length(xtype) ~= 1) || (abs(xtype) ~= 1)
    error('xtype must be 1 or -1')
end
if nargin < 5
    faxtype = 0;    % fax parity
end

x = x(:);                     % x is now a column vector
tax = tax(:);                 % tax is now a column vector

if mod(faxtype,2)
    fax = [0:nf]/2/nf;                  % frequency axis
    dfax = 1/2/nf*ones(1,nf+1);         % integration measure
    dfax([1 end]) = dfax([1 end])/2;    % edge pixels
else
    fax = ([1:nf]-1/2)/2/nf;            % frequency axis
    dfax = 1/2/nf*ones(1,nf);           % integration measure
end
theta = sqrt(2)*exp(i*2*pi*tax*fax);    % basis functions

if xtype == 1       % forward transform
    y = theta'*x;
elseif xtype == -1   % inverse transform
    y = real(theta*(x.*dfax'));
end

return
%%%%%%
