function [y,fax,dfax,phi]=osdgiven(xtype,x,tax,nf,phi,faxtype)
%   [y,fax,dfax,phi]=osdgiven(xtype,x,tax,nf,phi,faxtype) returns the forward
%   or inverse one-sided discrete windowed transform of order nf for tax
%   with regular sampling (integer values) not necessarily uniform
%   using window phi of odd length

if (nargin < 4) || (nargin > 6)
    help osdgiven, return
end
if  (length(xtype) ~= 1) || (abs(xtype) ~= 1)
    error('xtype must be 1 or -1')
end
if nargin < 5
    phi = 0;        % unit impulse
end
lphi = length(phi);
if ~mod(lphi,2)
    error('phi must be of odd length')
end
if ~isreal(phi)
    error('phi must be real')
end
if nargin < 6
    faxtype = 0;    % fax parity
end

tax = tax(:);           % tax is now a column vector
nd = length(tax);       % number of data entries
tax = tax-tax(1)+1;     % assign 1 to first entry
nt = tax(end);          % duration of data

if mod(faxtype,2)
    fax = [0:nf]/2/nf;                  % frequency axis
    dfax = 1/2/nf*ones(1,nf+1);         % integration measure
    dfax([1 end]) = dfax([1 end])/2;    % edge pixels
else
    fax = ([1:nf]-1/2)/2/nf;            % frequency axis
    dfax = 1/2/nf*ones(1,nf);           % integration measure
end
nff = nf+mod(faxtype,2);                % number of pixels

tau = (lphi-1)/2;           % find half width
tw = -tau:tau;                   % window time axis
tmax = nt+2*tau;                 % transform duration
phi = phi(:)';             % make phi row vector
phinrg = phi*phi';            % energy norm
%if phinrg ~= 2
if abs(phinrg-2) > 2*eps
    warning('renormalizing phi to unit energy x 2')
    phi = phi/sqrt(phinrg/2);
end

if xtype == 1   % forward transform
    xgap = zeros(1,nt); % zero pad gaps
    xgap(tax) = x(:);   % fill in data
    y = zeros(nff,tmax);
    for kf = 1:nff
        f = fax(kf); 
        theta = exp(i*2*pi*f*tw);
        psi = phi.*theta;
%plot(tw,real(psi),tw,imag(psi)), pause(.05)
        rowf = conv(psi,xgap);
%        rowf = conv(phi,exp(-i*2*pi*f*[1:nt]).*xgap);
        y(kf,:) = rowf;
    end
elseif xtype == -1  % inverse transform
    phi = fliplr(phi);
    faxtax = zeros(nff,nt);
    for kf = 1:nff
        f = fax(kf); 
        theta = exp(i*2*pi*f*tw);
        psi = phi.*theta;
        rowf = conv(psi,x(kf,:));
%        rowf = exp(i*2*pi*f*[1-tau*2:nt+tau*2]).*conv(phi,x(kf,:));
        faxtax(kf,:) = rowf(tau*2+[1:nt]);
    end
    y = real(dfax*faxtax(:,tax));
end % if xtype

return
%%%%%%

