function [y,fax,dfax,phi]=osdlayer(xtype,x,tax,nf,sigma,tau,faxtype)
%   [y,fax,dfax,phi]=osdlayer(xtype,x,tax,nf,sigma,tau,faxtype) returns the forward
%   or inverse one-sided discrete layered window transform of order nf for tax
%   with regular sampling (integer values) not necessarily uniform
%   using window parameter vectors sigma and tau

if (nargin < 4) || (nargin > 7)
    help osdlayer, return
end
if  (length(xtype) ~= 1) || (abs(xtype) ~= 1)
    error('xtype must be 1 or -1')
end
if nargin < 5
    sigma = inf;    % flat window
end
if nargin < 6
    tau = 0;        % unit impulse
end
if nargin < 7
    faxtype = 0;    % fax parity
end

tax = tax(:);           % tax is now a column vector
nd = length(tax);       % number of data entries
tax = tax-tax(1)+1;     % assign 1 to first entry
nt = tax(end);          % duration of data

if mod(faxtype,2)
    fax = [0:nf]/2/nf;                  % frequency axis
    dfax = 1/2/nf*ones(1,nf+1);         % integration measure
    dfax([1 end]) = dfax([1 end])/2;    % edge pixels
else
    fax = ([1:nf]-1/2)/2/nf;            % frequency axis
    dfax = 1/2/nf*ones(1,nf);           % integration measure
end
nff = nf+mod(faxtype,2);                % number of pixels

taumax = max(tau(:));               % maximum window size
tmax = nt+2*taumax;                 % transform duration
phi = zeros(1,2*taumax+1);          % accumulated window
nwa = 0;                            % number of windows accumulated
for sigman = sigma(:)', for taun = tau(:)'
    nwa = nwa+1;                        % next window accumulated
    twn = -taun:taun;                   % window time axis
    phin = exp(-pi*twn.^2/taun^2/sigman^2/2);  % window amplitude
    phin = phin/sqrt(phin*phin');       % normalized to unit energy
    phi(taumax+1+twn) = phi(taumax+1+twn)+phin.^2;
end, end
%phi = sqrt(phi/nwa*2);              % normalized to unit energy x 2
phi = sqrt(phi/sum(phi)*2);              % normalized to unit energy x 2
tw = -taumax:taumax;                % final window time axis

if xtype == 1   % forward transform
    xgap = zeros(1,nt); % zero pad gaps
    xgap(tax) = x(:);   % fill in data
    y = zeros(nff,tmax);
    for kf = 1:nff
        f = fax(kf); 
        theta = exp(i*2*pi*f*tw);
        psi = phi.*theta;
%plot(tw,real(psi),tw,imag(psi)), pause(.05)
        rowf = conv(psi,xgap);
%        rowf = conv(phi,exp(-i*2*pi*f*[1:nt]).*xgap);
        y(kf,:) = rowf;
    end
elseif xtype == -1  % inverse transform
    faxtax = zeros(nff,nt);
    for kf = 1:nff
        f = fax(kf); 
        theta = exp(i*2*pi*f*tw);
        psi = phi.*theta;
        rowf = conv(psi,x(kf,:));
%        rowf = exp(i*2*pi*f*[1-taumax*2:nt+taumax*2]).*conv(phi,x(kf,:));
        faxtax(kf,:) = rowf(taumax*2+[1:nt]);
    end
    y = real(dfax*faxtax(:,tax));
end % if xtype

return
%%%%%%

