function [y,fax,dfax]=tsdfourier(xtype,x,tax,nf,faxtype,foff)
%   [y,fax,dfax]=tsdfourier(xtype,x,tax,nf,faxtype,foff) returns the forward or
%   inverse two-sided discrete Fourier transform of order nf for tax
%   with regular sampling (integer values) not necessarily uniform

if (nargin < 4) || (nargin > 6)
    help tsdfourier, return
end
if  (length(xtype) ~= 1) || (abs(xtype) ~= 1)
    error('xtype must be 1 or -1')
end
if nargin < 5
    faxtype = 0;    % fax parity
end
if nargin < 6
    foff = 0;       % fax offset
end

x = x(:);                     % x is now a column vector
tax = tax(:);                 % tax is now a column vector

if mod(faxtype,2)
    fax = [-nf:nf]/2/nf;                % frequency axis
    dfax = 1/2/nf*ones(1,nf*2+1);       % integration measure
    dfax([1 end]) = dfax([1 end])/2;    % edge pixels
else
    fax = [-nf+1/2:nf-1/2]/2/nf;        % frequency axis
    dfax = 1/2/nf*ones(1,nf*2);         % integration measure
end
fax = fax+foff;                         % offset frequency axis
theta = exp(i*2*pi*tax*fax);            % basis functions

if xtype == 1       % forward transform
    y = theta'*x;
elseif xtype == -1   % inverse transform
    y = theta*(x.*dfax');
end

return
%%%%%%
